FeedbackPayload class

Constructors

FeedbackPayload({required String message, required String category, bool includeAppInfo = true})

Properties

category → String
final
hashCode → int
The hash code for this object.
no setterinherited
includeAppInfo → bool
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited