BaseSettingsScreenState<T extends BaseSettingsScreen> class abstract

Inheritance

Constructors

BaseSettingsScreenState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme ↔ AppTheme
getter/setter pairinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
darkThemeSettingWidget({bool value = false, bool enable = true, void onChanged(bool)?}) → Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
languageSettingWidget({required SupportLanguage language, void onItemPressed(SupportLanguage)?}) → Widget
moreAppsSettingWidget() → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLanguageSettingPressed({required SupportLanguage language, void onItemPressed(SupportLanguage)?}) → void
onStatusChanged() → Future<void>
inherited
onUnlockFeaturePressed() → Future<void>
productId() → String
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showInfoSettingWidget() → Widget
subscriptionId() → String?
themeSettingWidget({required void onItemSelected(int), required int themesCount, Widget separator = const SizedBox(width: 8), required (AppTheme, bool) itemBuilder(int)}) → Widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
unlockFeatureSettingWidget({bool value = false, bool enable = true, void onChanged(bool)?}) → Widget

Operators

operator ==(Object other) → bool
The equality operator.
inherited