InAppPurchaseUtils class
Utility class for managing in-app purchases.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
checkPurchase(
{required BaseSettings settings, List< String> productIds = const [], List<String> subscriptionIds = const [], void onCompleted()?}) → Future<void> - Checks previous purchases and queries product details.
-
dispose(
) → void - Disposes resources to prevent memory leaks.
-
findProductDetails(
String id) → ProductDetails? -
Finds the
ProductDetailsfor the given product ID. -
init(
) → void - Initializes the in-app purchase system.
-
listen(
{void onStatusChanged(PurchaseStatus, String?)?}) → void - Starts listening for purchase updates.
-
purchase(
String productId) → Future< void> - Initiates purchase of a given product ID.