ImageUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getAverageColor(Uint8List bytes)
→ Color
-
-
getContrastColor(Color color)
→ Color
-
-
getImageFilesFromFolder(String folderPath)
→ Future<List<File>>
-
-
getOppositeColorFromImage(Uint8List bytes)
→ Future<Color>
-
-
getRegionAverage(Uint8List bytes, {String region = 'center', int step = 10})
→ Color
-
-
loadUiImage(String path, {required int width, required int height, bool fromAsset = true})
→ Future<Image>
-
-
oppositeColor(Color color)
→ Color
-
-
regionAverage(Image image, int startY, int endY, {int step = 10})
→ Color
-
-
toImage(Uint8List data, {int? width, int? height})
→ Future<Image>
-